@@ -19,10 +19,14 @@ class __Validate(object):
                     if ";" in filters:  # check 'AND' statement
                         and_filters = []
                         for f in filters.split(";"):
-                            and_filters.append(self.__create_filter_row(f.strip()))  # strip string for del spaces
+                            and_filters.append(
+                                self.__create_filter_row(f.strip())
+                            )  # strip string for del spaces
                         parsed_filters.append(and_filters)  # return list of AND filters
                         continue
-                    parsed_filters.append(self.__create_filter_row(filters.strip()))  # strip string for del spaces
+                    parsed_filters.append(
+                        self.__create_filter_row(filters.strip())
+                    )  # strip string for del spaces
         return parsed_filters
 
     def generate_mongo_query(self, parsed: dict) -> dict:
@@ -33,13 +37,21 @@ class __Validate(object):
         exclude = field.startswith('!')
         field = field.replace('!', '')
         if operator == 'in_':
-            query[f'{field}__regex' if not exclude else f'{field}__regex_ne'] = parsed['value']
+            query[f'{field}__regex' if not exclude else f'{field}__regex_ne'] = parsed[
+                'value'
+            ]
         elif operator == 'not_in':
-            query[f'{field}__regex_ne' if not exclude else f'{field}__regex'] = parsed['value']
+            query[f'{field}__regex_ne' if not exclude else f'{field}__regex'] = parsed[
+                'value'
+            ]
         elif operator == 'start':
-            query[f'{field}__startswith' if not exclude else f'{field}__not_startswith'] = parsed['value']
+            query[
+                f'{field}__startswith' if not exclude else f'{field}__not_startswith'
+            ] = parsed['value']
         elif operator == 'end':
-            query[f'{field}__endswith' if not exclude else f'{field}__not_endswith'] = parsed['value']
+            query[
+                f'{field}__endswith' if not exclude else f'{field}__not_endswith'
+            ] = parsed['value']
         elif operator == 'eq':
             query[f'{field}' if not exclude else f'{field}__ne'] = parsed['value']
         elif operator == 'not_eq':
@@ -61,7 +73,9 @@ class __Validate(object):
                 queries.append(query_dict)
             else:
                 queries.append(
-                    self.generate_mongo_query(parsed) if mongo else self.generate_django_orm_query(parsed)
+                    self.generate_mongo_query(parsed)
+                    if mongo
+                    else self.generate_django_orm_query(parsed)
                 )
         return queries
 
@@ -72,13 +86,19 @@ class __Validate(object):
         exclude = field.startswith('!')
         field = field.replace('!', '')
         if operator == 'in_':
-            query['filter' if not exclude else 'exclude'][f'{field}__iexact'] = parsed['value']
+            query['filter' if not exclude else 'exclude'][f'{field}__iexact'] = parsed[
+                'value'
+            ]
         elif operator == 'not_in':
             query['exclude' if not exclude else 'filter'][field] = parsed['value']
         elif operator == 'start':
-            query['filter' if not exclude else 'exclude'][f'{field}__startswith'] = parsed['value']
+            query['filter' if not exclude else 'exclude'][
+                f'{field}__startswith'
+            ] = parsed['value']
         elif operator == 'end':
-            query['filter' if not exclude else 'exclude'][f'{field}__endswith'] = parsed['value']
+            query['filter' if not exclude else 'exclude'][
+                f'{field}__endswith'
+            ] = parsed['value']
         elif operator == 'eq':
             query['filter' if not exclude else 'exclude'][field] = parsed['value']
         elif operator == 'not_eq':
@@ -97,7 +117,7 @@ class __Validate(object):
             "=$": "end",
             "=^": "start",
             "==": "eq",
-            "!=": "not_eq"
+            "!=": "not_eq",
         }
         for operator in operators:
             if operator in f:
@@ -114,9 +134,8 @@ class __Validate(object):
             exclude = True
             row['field'] = row['field'][1:]
         method = getattr(self, row['set'])
-        check_value = self.validate_obj.get(row['field'])
-        if check_value:
-            exist = method(row['value'], check_value)
+        check_value = self.validate_obj.get(row['field'], '')
+        exist = method(row['value'], check_value)
         return self.create_filter_result(exist, exclude)
 
     def validate_data(self):
