@@ -6,7 +6,10 @@ from rest_framework.exceptions import PermissionDenied
 from django.conf import settings
 
 
-__all__ = ('CredentialMixin', 'SmartAdminRequiredMixin', )
+__all__ = (
+    'CredentialMixin',
+    'SmartAdminRequiredMixin',
+)
 
 
 class BaseCredentialMixin(object):
@@ -22,15 +25,23 @@ class BaseCredentialMixin(object):
         elif 'HTTP_AUTHORIZATION' in request.META and "platform_id" in request.GET:
             token = request.META["HTTP_AUTHORIZATION"]
         else:
-            raise PermissionDenied({"status": "error", "message": "you don't have permission to access"})
+            raise PermissionDenied(
+                {"status": "error", "message": "you don't have permission to access"}
+            )
         try:
-            response = requests.get(f"{self.url}api/check-platform/?platform_id={request.GET['platform_id']}",
-                                    headers={"executetoken": token})
+            response = requests.get(
+                f"{self.url}api/check-platform/?platform_id={request.GET['platform_id']}",
+                headers={"executetoken": token},
+            )
         except requests.ConnectionError:
-            raise PermissionDenied({"status": "error", "message": "Authorization failed."})
+            raise PermissionDenied(
+                {"status": "error", "message": "Authorization failed."}
+            )
 
         if response.status_code != 200:
-            raise PermissionDenied({"status": "error", "message": "Authorization failed."})
+            raise PermissionDenied(
+                {"status": "error", "message": "Authorization failed."}
+            )
 
         return response.json()["auth_info"]
 
@@ -39,20 +50,26 @@ class BaseCredentialMixin(object):
         user_id = user_info["id"]
         if user_id in (19, 22, 23, 55):
             return user_id
-        raise PermissionDenied({"status": "error", "message": "This endpoint only for smart admin users."})
+        raise PermissionDenied(
+            {"status": "error", "message": "This endpoint only for smart admin users."}
+        )
 
 
 class CredentialMixin(BaseCredentialMixin):
 
     check_credential = True
     with_smart_auth = True
-    
+
     # method for dashboard app
     def get_check_dash_auth(self, request):
         if 'HTTP_EXECUTETOKEN' not in request.META:
-            raise PermissionDenied({"status": "error", "message": "you don't have permission to access"})
-        auth_info = requests.post(f"{self.url}api/check-auth/",
-                                  headers={"executetoken": request.META['HTTP_EXECUTETOKEN']}).json()
+            raise PermissionDenied(
+                {"status": "error", "message": "you don't have permission to access"}
+            )
+        auth_info = requests.post(
+            f"{self.url}api/check-auth/",
+            headers={"executetoken": request.META['HTTP_EXECUTETOKEN']},
+        ).json()
         if "is_admin" not in auth_info:
             raise PermissionDenied({"status": "error", "message": "Invalid dash user."})
 
@@ -84,7 +101,9 @@ class CredentialMixin(BaseCredentialMixin):
 
         credential = model.objects.filter(**params).first()
         if not credential:
-            raise PermissionDenied({"status": "error", "message": "Credential does not exist."})
+            raise PermissionDenied(
+                {"status": "error", "message": "Credential does not exist."}
+            )
 
         return credential
 
@@ -100,7 +119,7 @@ class CredentialMixin(BaseCredentialMixin):
     def get_credential_model(self):
         if hasattr(settings, 'CREDENTIAL_MODEL'):
             module_path, model = settings.CREDENTIAL_MODEL.rsplit('.', 1)
-            module = importlib.import_module(module_path) 
+            module = importlib.import_module(module_path)
             return getattr(module, model)
         raise AttributeError('miss CREDENTIAL_MODEL in django settings')
 
