@@ -10,7 +10,12 @@ from rest_framework.exceptions import PermissionDenied, NotAcceptable
 from .mixins import CredentialMixin
 from .pagination import LimitOffsetPaginationListAPIView
 
-__all__ = ('HomeAPIView', 'BaseCredentialModelViewSet', 'BaseReportListAPIView', 'BaseGetCredentialAPIView')
+__all__ = (
+    'HomeAPIView',
+    'BaseCredentialModelViewSet',
+    'BaseReportListAPIView',
+    'BaseGetCredentialAPIView',
+)
 
 
 class BaseCredentialModelViewSet(CredentialMixin, ModelViewSet):
@@ -53,6 +58,7 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
     model = None
     select_related_fields = ()  # must be tuple or list
     with_platforms_sample = False
+    order_by_fields = ()  # must be tuple or list
 
     def get_model(self):
         if not self.model:
@@ -60,25 +66,30 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
         return self.model
 
     def get_queryset(self):
-        if self.select_related_fields and isinstance(self.select_related_fields, (tuple, list)):
-            qs = self.get_model().objects.select_related(
-                *self.select_related_fields
-            ).filter(integration_id=self.integration_id,
-                     date__range=[
-                         self.date_from, self.date_to
-                     ])
+        if self.select_related_fields and isinstance(
+            self.select_related_fields, (tuple, list)
+        ):
+            qs = (
+                self.get_model()
+                .objects.select_related(*self.select_related_fields)
+                .filter(
+                    integration_id=self.integration_id,
+                    date__range=[self.date_from, self.date_to],
+                )
+            )
         else:
-            qs = self.get_model().objects.filter(integration_id=self.integration_id,
-                                                 date__range=[
-                                                     self.date_from, self.date_to
-                                                 ])
+            qs = self.get_model().objects.filter(
+                integration_id=self.integration_id,
+                date__range=[self.date_from, self.date_to],
+            )
         if self.with_platforms_sample:
             return qs.filter(platform_id=self.platform_id)
+        if self.order_by_fields:
+            return qs.order_by(','.join(self.order_by_fields))
         return qs
 
 
 class BaseGetCredentialAPIView(CredentialMixin, APIView):
-
     def get_redirect_uri(self):
         """Create in this method redirect uri
             Example: https://oauth.yandex.ru/authorize?response_type=code&client_id={settings.YANDEX_APP_CLIENT_ID}&state={self.get_state()}&redirect_uri={redirect_url}
@@ -87,10 +98,14 @@ class BaseGetCredentialAPIView(CredentialMixin, APIView):
 
     def check_auth_params(self):
         """This method for check auth params"""
-        if "callback_url" not in self.request.GET \
-                or "token" not in self.request.GET \
-                or "platform_id" not in self.request.GET:
-            raise PermissionDenied({"status": "error", "message": "You dont have permission to access."})
+        if (
+            "callback_url" not in self.request.GET
+            or "token" not in self.request.GET
+            or "platform_id" not in self.request.GET
+        ):
+            raise PermissionDenied(
+                {"status": "error", "message": "You dont have permission to access."}
+            )
         return self.request
 
     def get_state(self):
